========================
Ball and Beam (ballbeam)
========================

This example is a simulation study of the "Ball and Beam" system, as it is
described in [Hauser92]_ .

.. image:: ballbeam.*

.. [Hauser92] Hauser, J.; Sastry, S.; Kokotovic, P.
    Nonlinear Control Via Approximate
    Input-Output-Linearization: The Ball and Beam Example. IEEE Trans. on
    Automatic Control, 1992, vol 37, no. 3, pp. 392-398